if-else
-------
This directory was created in response to a bug in the code generation of
else statements, and so this directory was therefore created to test a specific
failure case.

I'm leaving it here to allow testing for regression. It also acts as a simple
example of how pyxie programs can be written, compiled etc.
